@@ -159,7 +159,7 @@ where
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::Robot;
+    use crate::{APIError, Robot};
     use serial_test::serial;
 
     #[test]
@@ -184,6 +184,17 @@ mod tests {
         );
     }
 
+    #[test]
+    #[ignore]
+    pub fn get_nonexistent_server() {
+        let robot = Robot::default();
+
+        assert!(matches!(
+            robot.get_server(1),
+            Err(Error::API(APIError::ServerNotFound { .. }))
+        ));
+    }
+
     #[test]
     #[ignore]
     #[serial(server_name)]
